==> babelwidget-2024.1.tar.gz: babelwidget-2024.1/babelwidget/backend/pyqt5/function.py <==
# Copyright CNRS/Inria/UniCA
# Contributor(s): Eric Debreuve (since 2023)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

import typing as h

import PyQt5.QtCore as core

NewMessage = core.pyqtSignal


def CreateMessageCanal(
    messenger: core.QObject, message: str, AcknowledgeMessage: h.Callable, /
) -> None:
    """"""
    signal: core.pyqtBoundSignal = getattr(messenger, message)
    signal.connect(AcknowledgeMessage)

==> babelwidget-2024.2.tar.gz: babelwidget-2024.2/babelwidget/backend/pyqt5/function.py <==
# Copyright CNRS/Inria/UniCA
# Contributor(s): Eric Debreuve (since 2023)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

import typing as h

import PyQt5.QtCore as core

NewMessage = core.pyqtSignal


def CreateMessageCanal(
    messenger: core.QObject,
    message: str,
    AcknowledgeMessage: h.Callable,
    /,
    *args,
    **kwargs,
) -> None:
    """"""
    signal: core.pyqtBoundSignal = getattr(messenger, message)
    if (args.__len__() > 0) or (kwargs.__len__() > 0):
        AcknowledgeMessage = lambda: AcknowledgeMessage(*args, **kwargs)
    signal.connect(AcknowledgeMessage)
